# frozen_string_literal: true

# Starts the DynamoDB client.
# Always uses default SDK authentication, but takes endpoint and region from config, if provided.

require_relative '../../create_schema'

Application.boot(:dynamodb, from: :platform) do
  configure do |config|
    config.endpoint = container[:settings].dynamodb_url
    config.region = container[:settings].dynamodb_region
    config.role_arn = container[:settings].dynamodb_role_arn
  end

  after(:start) do |target|
    # Register an alias
    target.register('dynamodb.client', target[:dynamodb])

    if ENV['DEPLOYMENT_PROVIDER'] == 'gcp'
      configure_aws_and_tables
    end

    # `call: false` makes this a Proc, which will be run each time it's resolved
    target.register('dynamodb.flow_down_table', call: false) do
      ::Aws::DynamoDB::Table.new(self[:settings].dynamodb_table_name,
                                 client: target[:dynamodb])
    end
  end
end
